#ifndef _MOGL_H_
#define _MOGL_H_

// vlastne triedy
#include "m3Dmath.h"
#include "mCamera.h"
#include "mText.h"
#include "mTexture.h"

typedef struct _material { // struktura OpenGL materialu
 GLfloat amb[4],dif[4],spe[4],amb_dif[4],emi[4];
 GLfloat shi,transp,sillum[4];
};

typedef struct _light {    // struktura OpenGL svetla
 GLfloat amb[4],dif[4],spe[4];
 GLfloat pos[4],spot[3];
};

// trieda premennych a funkcii pre pracu s OpenGL
class mOGL {
public:
 mOGL();          // konstruktor
 virtual ~mOGL(); // destruktor

 GLint ViewPort[4]; // rozmery okna

 mCamera ogl_Camera[8]; // pouzite kamery

 bool gl_initialize(void); // inicializacia OpenGL
 int gl_draw(void);        // vykreslenie OpenGL sceny
 int gl_iddle(void);       // casovo zavisla uprava objektov, resp. sceny

 // zmena stavov OpenGL stavoveho stroja -----------------------------------
 void change_PolygonMode(void);   // zmena sposobu zobrazenia objektov
 void change_HelpOnOff(void);     // zap/vyp vypisu helpu
 void change_DrawType(void);      // zmena pohladu na scenu
 void change_LightPos(GLfloat x,GLfloat y,GLfloat z); // zmena polohy svetla
private:
 GLuint Cnum; // cislo pouzitej OpenGL kamery

 _matrix OGLM; // pre ulozenie prvkov OpenGL matice

 _material ogl_Material[8]; // pouzite materialy

 _light ogl_Light[8];       // pouzite svetla
 GLfloat Lrotx,Lroty,Lposz; // pre zmenu rotacie a polohy svetla
 _vector Lp0, Lp1;          // pre vypocet polohy svetla

 GLfloat StartInfoPos;                // pozicia vypisu start info
 void PrintStartInfo(char *infotext); // vypis info pocas startu aplikacie

 GLuint t_a,t_b,t_c; // pomocne premenne

 GLint ogl_State[2]; // pre zistovanie stavov OpenGL stavoveho stroja

 GLubyte lighting_onoff;  // indikator zap/vyp osvetlenia
 GLubyte help_onoff;      // indikator zap/vyp vypisu helpu
 GLubyte scene_draw_type; // pohlad na scenu

 char fname[128]; // pre ulozenie retazcov (cesta k suboru)

 // objekt, ktory vrha tien ------------------------------------------------
 s3DObject shadow_obj;      // objekt, ktory vrha tien
 GLfloat shadow_obj_pos[3]; // poloha objektu, ktory vrha tien
 GLfloat shadow_obj_rot[3]; // rotacia objektu, ktory vrha tien

 int ReadShadowObject(char *datafile,s3DObject *obj); // nacitanie objektu zo suboru
 void ShadowObjectFaces(s3DObject *obj);              // priprava objektu pre vrhanie tiena
 void DrawShadowObject(s3DObject obj);                // vykreslenie objektu
 void DrawShadow(s3DObject obj,GLfloat *lightpos);    // vykreslenie tiena

 GLfloat S;      // pomocna premenna
 GLuint P1,P2;   // pre indexy vertexov
 s3DPoint V1,V2; // pre vektory

 // dalsie pouzite triedy --------------------------------------------------
 m3Dmath ogl_3Dmath;   // instancia triedy m3Dmath - praca s mat-geom vypoctami
 mText ogl_Text;       // instancia triedy mText - praca s textom
 mTexture ogl_Texture; // instancia triedy mTexture - praca s texturou
};

#endif
